@@ -7,8 +7,13 @@ COMMAND_COLOR = "Color"
 COMMAND_CT = "CT"
 COMMAND_DIMMER = "Dimmer"
 COMMAND_FADE = "Fade"
+COMMAND_FANSPEED = "FanSpeed"
 COMMAND_POWER = "Power"
 COMMAND_SCHEME = "Scheme"
+COMMAND_SHUTTER_CLOSE = "ShutterClose"
+COMMAND_SHUTTER_OPEN = "ShutterOpen"
+COMMAND_SHUTTER_POSITION = "ShutterPosition"
+COMMAND_SHUTTER_STOP = "ShutterStop"
 COMMAND_SPEED = "Speed"
 COMMAND_WHITE = "White"
 
@@ -28,6 +33,7 @@ CONF_ONLINE = "onln"
 CONF_OPTIONS = "so"
 CONF_PREFIX = "tp"
 CONF_SENSOR = "sn"
+CONF_SHUTTER_OPTIONS = "sho"
 CONF_STATE = "state"
 CONF_RELAY = "rl"
 CONF_SW_VERSION = "sw"
@@ -40,6 +46,11 @@ CONF_VERSION = "ver"
 CONF_MANUFACTURER = "manufacturer"
 CONF_NAME = "name"
 
+FAN_SPEED_OFF = 0
+FAN_SPEED_LOW = 1
+FAN_SPEED_MEDIUM = 2
+FAN_SPEED_HIGH = 3
+
 LST_NONE = 0
 LST_SINGLE = 1
 LST_COLDWARM = 2
@@ -72,6 +83,7 @@ RL_SHUTTER = 3
 
 RSLT_ACTION = "Action"
 RSLT_POWER = "POWER"
+RSLT_SHUTTER = "Shutter"
 RSLT_STATE = "STATE"
 RSLT_TRIG = "TRIG"
 
@@ -136,6 +148,14 @@ SENSOR_UNIT_PRESSURE = "PressureUnit"
 SENSOR_UNIT_SPEED = "SpeedUnit"
 SENSOR_UNIT_TEMPERATURE = "TempUnit"
 
+SHUTTER_DIRECTION = "Direction"
+SHUTTER_DIRECTION_DOWN = -1
+SHUTTER_DIRECTION_STOP = 0
+SHUTTER_DIRECTION_UP = 1
+SHUTTER_POSITION = "Position"
+
+SHUTTER_OPTION_INVERT = 1
+
 # #### UNITS OF MEASUREMENT ####
 # Power units
 POWER_WATT = "W"
